Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DotProduct ¶
DotProduct calculates the dot product of two vectors using NEON or AVX SIMD instructions if supported, otherwise it falls back to the standard implementation.
Parameters:
- left: the first vector
- right: the second vector
- result: the initial value of the result
Returns:
- the dot product of the two vectors
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.